pub enum AlertEffect {
NoService,
ReducedService,
SignificantDelays,
Detour,
AdditionalService,
ModifiedService,
OtherEffect,
UnknownEffect,
StopMoved,
NoEffect,
AccessibilityIssue,
}Expand description
AlertEffect : The effect of this problem on the affected entity. The effect of this problem on the affected entity.
Variants
NoService
ReducedService
SignificantDelays
Detour
AdditionalService
ModifiedService
OtherEffect
UnknownEffect
StopMoved
NoEffect
AccessibilityIssue