pub struct Transfer {
pub to: Box<Place>,
pub default: Option<f64>,
pub foot: Option<f64>,
pub foot_routed: Option<f64>,
pub wheelchair: Option<f64>,
pub wheelchair_routed: Option<f64>,
pub wheelchair_uses_elevator: Option<bool>,
pub car: Option<f64>,
}Expand description
Transfer : transfer from one location to another
Fields
to: Box<Place>default: Option<f64>optional; missing if the GTFS did not contain a transfer transfer duration in minutes according to GTFS (+heuristics)
foot: Option<f64>optional; missing if no path was found (timetable / osr) transfer duration in minutes for the foot profile
foot_routed: Option<f64>optional; missing if no path was found with foot routing transfer duration in minutes for the foot profile
wheelchair: Option<f64>optional; missing if no path was found with the wheelchair profile transfer duration in minutes for the wheelchair profile
wheelchair_routed: Option<f64>optional; missing if no path was found with the wheelchair profile transfer duration in minutes for the wheelchair profile
wheelchair_uses_elevator: Option<bool>optional; missing if no path was found with the wheelchair profile true if the wheelchair path uses an elevator
car: Option<f64>optional; missing if no path was found with car routing transfer duration in minutes for the car profile