pub struct Alert {Show 15 fields
pub communication_period: Option<Vec<TimeRange>>,
pub impact_period: Option<Vec<TimeRange>>,
pub cause: Option<AlertCause>,
pub cause_detail: Option<String>,
pub effect: Option<AlertEffect>,
pub effect_detail: Option<String>,
pub url: Option<String>,
pub header_text: String,
pub description_text: String,
pub tts_header_text: Option<String>,
pub tts_description_text: Option<String>,
pub severity_level: Option<AlertSeverityLevel>,
pub image_url: Option<String>,
pub image_media_type: Option<String>,
pub image_alternative_text: Option<String>,
}Expand description
Alert : An alert, indicating some sort of incident in the public transit network.
Fields
communication_period: Option<Vec<TimeRange>>Time when the alert should be shown to the user. If missing, the alert will be shown as long as it appears in the feed. If multiple ranges are given, the alert will be shown during all of them.
impact_period: Option<Vec<TimeRange>>Time when the services are affected by the disruption mentioned in the alert.
cause: Option<AlertCause>cause_detail: Option<String>Description of the cause of the alert that allows for agency-specific language; more specific than the Cause.
effect: Option<AlertEffect>effect_detail: Option<String>Description of the effect of the alert that allows for agency-specific language; more specific than the Effect.
url: Option<String>The URL which provides additional information about the alert.
header_text: StringHeader for the alert. This plain-text string will be highlighted, for example in boldface.
description_text: StringDescription for the alert. This plain-text string will be formatted as the body of the alert (or shown on an explicit "expand" request by the user). The information in the description should add to the information of the header.
tts_header_text: Option<String>Text containing the alert’s header to be used for text-to-speech implementations. This field is the text-to-speech version of header_text. It should contain the same information as headerText but formatted such that it can read as text-to-speech (for example, abbreviations removed, numbers spelled out, etc.)
tts_description_text: Option<String>Text containing a description for the alert to be used for text-to-speech implementations. This field is the text-to-speech version of description_text. It should contain the same information as description_text but formatted such that it can be read as text-to-speech (for example, abbreviations removed, numbers spelled out, etc.)
severity_level: Option<AlertSeverityLevel>Severity of the alert.
image_url: Option<String>String containing an URL linking to an image.
image_media_type: Option<String>IANA media type as to specify the type of image to be displayed. The type must start with "image/"
image_alternative_text: Option<String>Text describing the appearance of the linked image in the image field (e.g., in case the image can’t be displayed or the user can’t see the image for accessibility reasons). See the HTML spec for alt image text.